Date: 01 4, 2002 11:59:25 AM

# fprintxvar

## Purpose

OBSOLETE. To fileName, print the value of the variable var in the ordth context node.

## Syntax

fprintxvar(fileNname, var, ord)

fileName - type: str
var - type:
ord - type:

## Returns

## Remarks

The output file (fileName) must be set up in advance using openfile, fileout or an output statement.

## Example

## See Also

fprintgvar, fprintnvar, openfile, fileout, POST Actions